  /**
  * Customisable Popup made purely with VanillaJS
  * All customisations done in constructor function
  * Set style rules and message
  */
 class VanillaPopup {
  // Init 
  constructor() {
    this.removeToken = true;                                                // set to true to always remove token from localStorage, for testing purposes

    // Set Vars
    this.targetNode = document.querySelector("body");                       // Which element to inject message box into, default is the body element
    this.currTime   = new Date().getTime();                                 // Store current time string in variable for validation and storage
    this.readTime   = window.localStorage.getItem('vanillaPopupReadTime');  // leverage localStorage to store and check for read token
    this.daysToShowMessageAgain = 0;                                        // Presuming nobody would want to show the same message more than once a day

    // Message Content
    this.messageTitle = `<h1 style="text-align: center;"><span style="color: #000000;">WARNING!</span></h1>`;   
    this.messageBody  = `
    <span style="color: #000000;"><b>NEVER</b> make payments to any external wallet addresses or account details. provided by anyone. Our Staffs will NEVER ask you to send money to any wallet address, western union, or bank account DIFFERENT from those provided only within our website. Neither will you be asked to send payment to help you fund your account or complete your investment.</span>
<p style="text-align: left;"><span style="color: #000000;">Always be vigilant and always inquire from our official support email <span style="color: #39008F;"><a style="color: #39008F;" href="mailto:support@pathwayfigures.pro">support@pathwayfigures.pro</a></span> to confirm any of such claims.</span></p>
    `;
    
    // Style Rules
    this.messageBoxBgColor      = "rgba(242,241,241,0.89)";
    this.messageBoxFontColor    = "#000000";

    this.messageHeaderBgColor   = "#ffffff";
    this.messageHeaderFontColor = "#111111";

    this.closeIconColor         = "#111111";
    this.closeIconHoverColor    = "#a52a2a";

    this.messageBoxMinWidth     = "40%";
    this.messageBoxBorderRadius = "17px";
    

    /**
     * Number of days before pop up will be shown again in microtime
     */
    this.maxTimeAllowed = 3 * 3 * 0.000278 * 1000 * this.daysToShowMessageAgain;    // "One Day" times number of days set
    /**
      * check if user has read the popup yet, 
      * or if user has extended past the time set
      * before showing the message again
      */
    if( !this.readTime || this.currTime - this.readTime > this.maxTimeAllowed ) {
      this.showPopup();
    }
  }
  
  /**
    * Main function to show popup
    */
  showPopup() {

    // create and inject styles before creating Div to ensure proper styling
    const styles      = document.createElement("style");
    styles.innerHTML  = this.setStyleContent();
    this.targetNode.appendChild(styles);

    // create main div
    const msgBoxDiv = document.createElement("div");
    msgBoxDiv.setAttribute("id", "vanilla-msg-box");
    msgBoxDiv.innerHTML = this.setMessageBody();
    this.targetNode.appendChild(msgBoxDiv);

    // create close box event listener
    document.querySelector("#vanilla-box-close").addEventListener("click", () => {
      // add token to local storage only after popup is closed
      this.removeToken || window.localStorage.setItem("vanillaPopupReadTime", this.currTime);
      this.targetNode.removeChild(msgBoxDiv);
    });

  }

  /**
   * SetMessageBody
   * format the content of the message box
   */
  setMessageBody() {
    return `
    <div id="vanilla-box-wrapper">
      <div id="vanilla-box-header">
        <h1>${this.messageTitle}</h1>
        <span id="vanilla-box-close"><i class="fa fa-times fa-2x"></i></span>
      </div>
      <div id="vanilla-box-content">
        ${this.messageBody}
      </div>
    </div>
    `
  }

  /**
   * SetStyleContent
   * Styles created within Javascript file as well
   * Prevent creating extra files for pop up
   */
  setStyleContent() {
    return `
    #vanilla-msg-box {
      position: fixed;
      font-family: poppins;
      background-color: rgba(255,255,255,0);
      z-index: 999999;
      top: 0;
      left: 60px;
      right: 10px;
      width: 70%;
      height: 100vh;
      display: flex;
      justify-content: center;
      align-items: center;
    }
    #vanilla-box-wrapper{
      background-color: ${this.messageBoxBgColor};
      min-width: ${this.messageBoxMinWidth};
      border-radius: ${this.messageBoxBorderRadius};
    }
    #vanilla-box-header {
      background-color: ${this.messageHeaderBgColor};
      color: ${this.messageHeaderFontColor};
      display: flex;
      justify-content: space-between;
      padding: 20px;
      border-top-left-radius: ${this.messageBoxBorderRadius};
      border-top-right-radius: ${this.messageBoxBorderRadius};
    }
    #vanilla-box-header h1 {
      margin: 0;
    }
    #vanilla-box-header #vanilla-box-close {
      color: ${this.closeIconColor};
      transition: all 0.2s ease; 
    }
    #vanilla-box-header #vanilla-box-close:hover {
      cursor: pointer;
      transform: scale(1.1);
      color: ${this.closeIconHoverColor};
    }
    #vanilla-box-content {
      padding: 20px;
    }
    `;
  }
}

// instantiate class
const vanillaPopup = new VanillaPopup();